import { doFetch, doFetchGet } from "@/components/axios/api";
import url from "@/components/axios/url";
import {
  checkFalse,
  checkStatus,
  checkSuccess
} from "../../../../static/js/checkStatus";
import authMethods from "@/mixins/auth";
import defaultImg from "../../../../static/img/default.png";
import { formatLongTime } from "@/utils/utils";
import FreezeDialog from "./components/dialog/freeze.vue";
import MemberFieldsDialog from "./components/dialog/fieldsSettingDialog.vue";
import ExportFieldsDialog from "./components/dialog/fieldsSettingDialog.vue";
export default {
  name: "forzenlist",
  components: {
    ExportFieldsDialog,
    MemberFieldsDialog,
    FreezeDialog
  },
  mixins: [authMethods],
  filters: {
    formatDate(val, format) {
      if (!val || val == -1) return format == "hms" ? "" : "--";
      let str = formatLongTime(val, 1);
      let arr = str.split(" ");
      if (format == "ymd") {
        return arr[0];
      } else if (format == "hms") {
        return arr[1] || "";
      }
      return str;
    },
    formatCardName(val) {
      if (val) {
        if (val.length > 10) {
          val = val.substr(0, 10) + "...";
        }
      }
      return val;
    },
    formatMember(val) {
      if (val) {
        if (val.length > 3) {
          val = val.substr(0, 3) + "...";
        }
      }
      return val;
    },
    formatPhone(value) {
      if (!value) {
        return "--";
      }
      if (value.length != 11) {
        return value;
      }
      return `${value.substr(0, 3)}****${value.substr(7, 4)}`;
    }
  },
  data() {
    return {
      freezeDialogOptions: {
        count: 1,
        isBatchFreeze: 0,
        visible: false
      },
      exportData: {
        projectName: "member", // 当前项目名
        dialogVisible: false,
        type: 1,
        excelUrl: url.exceptionMemberExportExcel, // 下载数据的地址
        params: {} // 传递的参数
      },
      dialogMemberFieldVisible: false,
      dialogExportFieldVisible: false,
      defaultImg,
      settingType: 0, // 0未查询 1已设置 2未设置
      selectPage: {
        type: 0,
        dataReady: true
      },
      searchData: {
        memberCardStatus: "", //会员状态
        phoneNameCard: "", // 搜索字段
        pageName: "allCustomer",
        pageSize: 20,
        currentPage: 1,
        sortColName: "", // 排序字段
        sortType: "", // 排序方式
        showFields: "-1"
      },
      load: false,
      total: 0,
      memberFields: [], // 顶部标题配置
      exportFields: [], // 导出顶部配置
      frozenList: [],
      multipleList: [],

      abnormalSettingSave: 0
    };
  },
  created() {
    if (JSON.parse(sessionStorage.getItem("frozenListSearchData"))) {
      this.searchData = JSON.parse(
        sessionStorage.getItem("frozenListSearchData")
      );
    }
    let abnormalSettingSave = sessionStorage.getItem("AbnormalSettingSave");
    if (+abnormalSettingSave) {
      sessionStorage.removeItem("AbnormalSettingSave");
      this.$message({
        message:
          "异常会员规则配置已修改，如需解冻此前异常转冻结的会员，可前往冻结会员列表，筛选冻结方式，进行批量解冻",
        type: "warning",
        duration: 10000
      });
    }
  },
  beforeMount() {
    this.init();
  },
  watch: {
    searchData: {
      handler(newval) {
        sessionStorage.setItem("frozenListSearchData", JSON.stringify(newval));
      }
    },
    deep: true,
    immediate: true
  },
  methods: {
    init() {
      this.getSetting().then(res => {
        this.settingType = res;
        if (res != 1) {
          return;
        }
        this.load = true;
        this.getFindMemberFields(this.searchData.pageName)
          .then(list => {
            this.memberFields = list;
            this.getList();
          })
          .catch(() => {
            this.getList();
          });
      });
    },
    getSetting() {
      return new Promise(resolve => {
        doFetchGet(url.getAbnormalSetting)
          .then(res => {
            let { errorCode, result, message } = res.data || {};
            if (errorCode != 0) {
              resolve(1);
              checkFalse(message);
              return;
            }
            if (result) {
              let { exceptionRate, updateTime } = result;
              let nowDate = new Date();
              let updateDate = new Date(updateTime || 0);
              if (
                nowDate.getFullYear() == updateDate.getFullYear() &&
                nowDate.getMonth() == updateDate.getMonth() &&
                nowDate.getDate() == updateDate.getDate() &&
                exceptionRate == 0
              ) {
                resolve(3);
              } else if (exceptionRate > 3) {
                resolve(4);
              } else {
                resolve(1);
              }
            } else {
              resolve(2);
            }
            this.updateData(result);
          })
          .catch(() => {
            resolve(1);
          });
      });
    },
    getFindMemberFields(pageName) {
      return new Promise((resolve, reject) => {
        if (!pageName) {
          reject();
        }
        doFetch(url.findMemberFields, {
          pageName
        })
          .then(res => {
            let { errorCode, result } = res.data;
            if (errorCode === 0 && Array.isArray(result)) {
              resolve(result || []);
            } else {
              checkFalse(res.data.message);
              reject(res);
            }
          })
          .catch(err => {
            reject(err);
          });
      });
    },
    getList() {
      this.load = true;
      this.selectPage.dataReady = false;
      doFetchGet(url.getExceptionMemberList, this.searchData)
        .then(res => {
          this.selectPage.dataReady = true;
          this.load = false;
          let { errorCode, result } = res.data || {};
          if (errorCode === 0) {
            let { page, fields, fieldsStr } = result || {};
            let { result: list, totalCount } = page || {};
            this.frozenList = list || [];
            this.total = totalCount || 0;
          }
        })
        .catch(() => {
          this.load = false;
          this.selectPage.dataReady = true;
        });
    },
    sortChange(column) {
      let { prop, order } = column;
      this.searchData.sortColName = prop;
      if (order === "descending") {
        this.searchData.sortType = "desc";
      }
      if (order === "ascending") {
        this.searchData.sortType = "asc";
      }
      this.getList();
    },

    // 搜索选项改变时
    onSearchDataChange() {
      this.getList();
    },
    handleCurrentChange(val) {
      this.searchData.currentPage = val;
      this.getList();
    },
    unfreezeItem(item) {
      const datas = {
        memberIds: item.memberId, // 会员id
        remark: "", // 备注暂留
        //所有会员是2 当前是1 其他是0
        isCurrent: 1,
        status: item.frozenStatus == 1 ? 1 : 0, // 1 冻结 0 解冻
        phoneNameCard: item.cardNo || "" // 会员名称 手机号
      };
      doFetch(url.batchUpdateFrozen, datas).then(res => {
        if (res.data.errorCode === 0) {
          this.$message({
            message: "解冻成功",
            type: "success"
          });
          this.$nextTick(_ => {
            this.getList();
          });
        }
      });
    },
    freezeItem(item) {
      this.currentEditItem = item;
      this.freezeDialogOptions = {
        count: 1,
        isBatchFreeze: 0,
        visible: true
      };
    },

    submitMemberFields(fields) {
      doFetch(url.updateFields, {
        pageName: this.searchData.pageName,
        fields
      }).then(res => {
        if (res.data.errorCode === 0) {
          checkSuccess();
          // 需要对选中字段排序
          this.init();
        } else {
          checkFalse(res.data.message);
        }
      });
    },

    getUnfreezeCount() {
      return new Promise((resolve, reject) => {
        let { selectPage, multipleList, searchData } = this;
        // resolve(1)
        // return;
        if (searchData.memberCardStatus == 2) {
          resolve(0);
          return;
        }
        let data = {
          // memberCardStatus: searchData.memberCardStatus || "",
          all: selectPage.type == 2 ? 1 : 0,
          memberIds: multipleList.map(item => {
            return item.memberId;
          }),
          phoneNameCard: selectPage.type == 2 ? searchData.phoneNameCard : ""
        };

        doFetch(url.getUnfreezeCount, data)
          .then(res => {
            let { errorCode, message, result } = res.data;
            if (errorCode === 0) {
              resolve(result || 0);
            } else {
              checkFalse(message);
              reject(res.data);
            }
          })
          .catch(err => {
            reject(err);
          });
      });
    },
    // 批量冻结
    async batchFreeze() {
      let { multipleList } = this;
      if (!(multipleList && multipleList.length)) {
        return this.$message.warning("请勾选要修改的商户");
      }
      let count = await this.getUnfreezeCount();
      if (count) {
        this.freezeDialogOptions = {
          count: count,
          isBatchFreeze: 1,
          visible: true
        };
      } else {
        this.$message.warning("当前勾选的会员都为冻结状态，请重新勾选");
      }
    },
    // 点击确认冻结
    sureFreeze(options) {
      let data;
      // 是否批量判断
      if (this.freezeDialogOptions.isBatchFreeze) {
        let { selectPage, multipleList, searchData } = this;
        data = {
          // memberCardStatus: searchData.memberCardStatus || "",
          all: selectPage.type == 2 ? 1 : 0,
          memberIds: multipleList.map(item => {
            return item.memberId;
          }),
          frozenType: 1,
          remark: options.remark || "",
          phoneNameCard: selectPage.type == 2 ? searchData.phoneNameCard : ""
        };
      } else {
        let { currentEditItem } = this;
        data = {
          all: 0,
          memberIds: [currentEditItem.memberId],
          frozenType: 1,
          remark: options.remark || "",
          phoneNameCard: ""
        };
      }

      doFetch(url.exceptionMemberBatchFrozen, data)
        .then(res => {
          if (res.data.errorCode === 0) {
            checkSuccess();
            // 需要对选中字段排序
            this.init();
          }
        })
        .finally(() => {
          this.currentEditItem = null;
          this.freezeDialogOptions = {
            visible: false
          };
        });
    },
    // 搜索结果导出
    download() {
      if (this.total) {
        this.getFindMemberFields("memberTag").then(list => {
          this.exportFields = list;
          this.dialogExportFieldVisible = true;
        });
      } else {
        this.$message.warning("无数据");
      }
    },
    // 导出选项选择完毕 点击确定
    submitExportFields(fields) {
      doFetch(url.updateFields, {
        pageName: "memberTag",
        fields
      })
      doFetch(url.getEnableDownload).then(res=>{
        let {errorCode,result} = res.data;
        if (errorCode === 0 && result == 1) {
          this.exportData.type = 2;
        } else{
          this.exportData.type = 1;
        }
      })
      let {phoneNameCard,memberCardStatus} = this.searchData || {};
      this.exportData.params = {
        memberCardStatus,
        phoneNameCard,
        exportFields: fields
      }
      this.exportData.dialogVisible = true;
    },
    // 去配置
    toSettingPage() {
      this.$router.push({
        path: "/abnormal-setting"
      });
    },
    linkDetail(memberId) {
      if (!this.getCodeAuth("memberIntoCustomDetail")) return;
      this.$router.push({
        path: "/customerDetail",
        query: { memberId }
      });
    }
  }
};
